@@ -4,6 +4,7 @@ from .batches import (
     get_batches,
     update_batch_values,
     update_batch_feature_values,
+    update_batch_features_and_values,
     update_vector_batch_values,
 )
 from .data import (
@@ -26,6 +27,7 @@ __all__ = [
     "get_batches",
     "update_batch_values",
     "update_batch_feature_values",
+    "update_batch_features_and_values",
     "get_data_list",
     "get_time_values",
     "get_vector_time_values",
