@@ -527,44 +527,55 @@ def update_batch_feature_values(
 
 
 def update_batch_features_and_values(
-    batch_type: str,
+    batch_type_id: str,
     data: pd.DataFrame,
-    feature_columns: List[str],
-    units_ids: Optional[dict[str, str]] = None,
-    use_external_reference: bool = False,
+    feature_columns: Optional[List[str]] = None,
+    unit_ids: Optional[dict[str, str]] = None,
+    batch_id_index_name: str = "batch_id",
     api_credentials: Optional[_credentials.OIAnalyticsAPICredentials] = None,
-) -> None:
+):
     """
     It updates many batches values and features values at once
+
     Parameters
     ----------
-    batch_type: str
+    batch_type_id: str
         The id of the batch type to be retrieved.
     data: pd.DataFrame
         Object containing the features values and values to be uploaded:
         - The index contains the batch-ids;
         - The columns contains the features-ids and data-ids;
         - The data contains the features values.
-    feature_columns: array of str
+    feature_columns: list of str, optional
         List containing the names of the Dataframe's columns corresponding to the features-ids.
-    units_ids: dict[str, str], optional
+    unit_ids: dict[str, str], optional
         Dictionary with the unit-ids of data to be uploaded.
         Each key is a data-id that points to the corresponding unit-id.
-    use_external_reference: bool, default False
-        If True, the data are named using their external reference; if False, the OIAnalytics reference is used.
+    batch_id_index_name: str, default 'batch_id'
+        The name of the Dataframe's or Series's index.
     api_credentials: OIAnalyticsAPICredentials, optional
         The credentials to use to query the API. If None, previously set default credentials are used.
 
     Returns
     -------
-
+    A dictionary of the response from the API, containing the data insert report
     """
+
+    # Init
+    if feature_columns is None:
+        feature_columns = []
+
+    if unit_ids is None:
+        unit_ids = {}
+
+    data.index = data.index.get_level_values(batch_id_index_name)
+
     payload = []
     for index in data.index:
         payload.append(
             {
                 "batchId": index,
-                "batchTagCommands": [
+                "batchFeatureCommands": [
                     {"batchTagKeyId": tag, "batchTagValueValue": data.loc[index, tag],}
                     for tag in feature_columns
                     if data.loc[index, tag] is not None
@@ -573,7 +584,7 @@ def update_batch_features_and_values(
                     {
                         "dataId": data_id,
                         "value": data.loc[index, data_id],
-                        "unitId": units_ids.get(data_id),
+                        "unitId": unit_ids.get(data_id),
                     }
                     for data_id in [
                         col for col in data.columns if col not in feature_columns
@@ -582,14 +593,12 @@ def update_batch_features_and_values(
                 ],
             }
         )
-
-    endpoints.batches.update_batch_features_and_values(
-        batch_type=batch_type,
-        data=payload,
-        use_external_reference=use_external_reference,
-        api_credentials=api_credentials,
+    response = endpoints.batches.update_batch_features_and_values(
+        batch_type_id=batch_type_id, data=payload, api_credentials=api_credentials
     )
 
+    return response
+
 
 def update_vector_batch_values(
     data: Union[pd.DataFrame, List[pd.DataFrame]],
