@@ -281,6 +281,8 @@ class BatchValuesOutput:
                         data_type="batch", values_type="scalar", mode="object"
                     ).values()
                 }
+            else:
+                self.units = None
         else:
             self.units = units
 
@@ -296,7 +298,7 @@ class BatchValuesOutput:
             execution_report = get_default_execution_report()
         try:
             # send data
-            response = api.update_batch_values(
+            response = api.update_batch_features_and_values(
                 batch_type_id=self.batch_type_id,
                 data=self.data,
                 unit_ids=self.units,
@@ -438,9 +440,10 @@ class BatchFeaturesOutput:
 
         # send data
         try:
-            response = api.update_batch_feature_values(
+            response = api.update_batch_features_and_values(
                 batch_type_id=self.batch_type_id,
                 data=self.data,
+                feature_columns=list(self.data.columns),
                 batch_id_index_name=self.batch_id_index_name,
                 api_credentials=api_credentials,
             )
